# -*- coding: utf-8 -*-
# author: KoChan-s

from .colorizer import *

__copyright__ = "2020"
__version__ = "0.0.1"
__authors__ = ["KoChan-s"]

if __name__ == '__main__':
    print(Colorizer, colored)
